\name{BushApproval}
\alias{BushApproval}
\docType{data}
\title{U.S. President George Bush approval ratings}
\description{
  Approval ratings as reported by six different polls.
}
\usage{data(BushApproval)}
\format{
  A data frame with 323 observations on the following 3 variables.
  \describe{
    \item{date}{The date poll was begun (some take a few days)}
    \item{approval}{a numeric number between 0 and 100}
    \item{who}{a factor with levels \code{fox} \code{gallup} \code{newsweek} \code{time.cnn} \code{upenn} \code{zogby}}
  }
}
\details{
  A data set of approval ratings of George Bush over the time of his
  presidency, as reported by several agencies. Most polls were of size
  approximately 1,000 so the margin of error is about 3 percentage points.
}
\source{
  This is from data found at
  \url{http://www.pollingreport.com/BushJob.htm}. The idea came from an
  article in \emph{Salon}
  \url{http://salon.com/opinion/feature/2004/02/09/bush_approval/index.html}  by James K. Galbraith.
}
\examples{
data(BushApproval)
attach(BushApproval)

## Plot data with confidence intervals. Each poll gets different line type
## no points at first
plot(strptime(date,"\%m/\%d/\%y"),approval,type="n",
     ylab = "Approval Rating",xlab="Date",
     ylim=c(30,100)
     )

## plot line for CI. Margin or error about 3
## matlines has trouble with dates from strptime()
colors = rainbow(6)

for(i in 1:nrow(BushApproval)) {
  lines(rep(strptime(date[i],"\%m/\%d/\%y"),2),
        c(approval[i]-3,approval[i]+3),
        lty=as.numeric(who[i]),
        col=colors[as.numeric(who[i])]
        )
  
}

## plot points
points(strptime(date,"\%m/\%d/\%y"),approval,pch=as.numeric(who))

## add legend
legend((2003-1970)*365*24*60*60,90,legend=as.character(levels(who)),lty=1:6,col=1:6)
detach(BushApproval)
}
\keyword{datasets}

\eof
\name{DOTplot}
\alias{DOTplot}
\alias{DOTplot.default}
\alias{DOTplot.formula}
\alias{DOTplt}
\alias{DOTplot.formula}
\title{ Make big DOT plot likestripchart }
\description{
  A variant of the \code{stripchart} using big dots as the default.
}
\usage{
DOTplot(x, ...)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{x}{May be a vector, data frame, matrix (each column a variable),
  list or model formula. Treats each variable or group as a univariate
  dataset and 
  makes corresponding DOTplot.}
\item{\dots}{arguments passed onto
  \code{points}.}
}
\value{
  Returns the graphic only.
}
\author{ John Verzani}
\seealso{ See also as \code{\link{stripchart}}, \code{\link{dotplot}} }
\examples{
x = c(1,1,2,3,5,8)
DOTplot(x,main="Fibonacci",cex=2)
}
\keyword{ hplot }% at least one, from doc/KEYWORDS

\eof
\name{MLBattend}
\alias{MLBattend}
\docType{data}
\title{Major league baseball attendance data}
\description{
  Data on home-game attendance in Major League Baseball for the years
  1969-2000. 
}
\usage{data(MLBattend)}
\format{
  A data frame with 838 observations on the following 10 variables.
  \describe{
    \item{franchise}{Which team}
    \item{league}{American or National league}
    \item{division}{Which division}
    \item{year}{The year (the year 2000 is recorded as 0)}
    \item{attendance}{Actual attendance}
    \item{runs.scored}{Runs scored by the team during year}
    \item{runs.allowed}{Runs allows by the team during year}
    \item{wins}{Number of wins for season}
    \item{losses}{Number of losses for season}
    \item{games.behind}{A measure of how far from division winner the
    team was. Higher numbers are worse.}
  }
}
\source{
  This data was submitted to \emph{The Journal of Statistical Education}
  by James J. Cochran, \url{http://www.amstat.org/publications/jse/v10n2/datasets.cochran.html}.
}
\examples{
data(MLBattend)
boxplot(attendance ~ franchise, MLBattend)
with(MLBattend, cor(attendance,wins))
}
\keyword{datasets}

\eof
\name{OBP}
\alias{OBP}
\docType{data}
\title{ On base percentage for 2002 major league baseball season}
\description{
  The on base percentage, \code{OBP}, is a measure of how often a players gets
  on base. It differs from the more familiar batting average, as it
  include bases on balls (\code{BB}) and hit by pitches (\code{HBP}). The exact
  formula is \code{OBP = (H + BB + HBP) / (AB + BB + HBP + SF)}.
}
\usage{data(OBP)}
\format{
 438 numbers between 0 and 1 corresponding the on base \dQuote{percentage} for
 the 438 players who had 100 or more at bats in the 2002 baseball
 season. The "outlier" is Barry Bonds. 
}
\source{
  This data came from the  interesting Lahman baseball data base
  \url{http://www.baseball1.com/}. The names attribute uses the \code{playerID}
  from this database. Unfortunately there were some errors in the
  extraction from the original data set. Consult the original for
  accurate numbers.
}
\examples{
data(OBP)
hist(OBP)
OBP[OBP>.5]			# who is better than 50%? (only Barry Bonds)
}
\keyword{datasets}

\eof
\name{age.universe}
\alias{age.universe}
\docType{data}
\title{ Best estimate of the age of the universe}
\description{
  For years people have tried to estimate the age of the universe. This
  data set collects a few estimates starting with lower bounds using
  estimates for the earth's age. 
}
\usage{data(age.universe)}
\format{
  A data frame with 15 observations on the following 4 variables.
  \describe{
    \item{lower}{a numeric vector}
    \item{upper}{a numeric vector}
    \item{year}{a numeric vector}
    \item{source}{Short description of source}
  }
}
\details{
  In the last two decades estimates for the age of the universe have
  been greatly improved. As of 2003, the best guess is 13.7 billion
  years with a margin of error of 1 percent. This last estimate is found
  by WMAP using microwave background radiation. Previous estimates were
  also based on estimates of Hubble's constant, and dating of old stars.
}
\source{
  This data was collected from the following web sites:
  \url{http://www.cwru.edu/pubaff/univcomm/2003/1-03/kraussuniverse.htm},
  \url{http://www.astro.ucla.edu/~wright/age.html},
  \url{http://www.lhup.edu/~dsimanek/cutting/ageuniv.htm}, and
  \url{http://map.gsfc.nasa.gov/m_uni/uni_101age.html}.
  
}
\examples{
data(age.universe)
n = nrow(age.universe)
x = 1:15;names(x) = age.universe$year
plot(x,age.universe$upper,ylim=c(0,20))
points(x,age.universe$lower)
with(age.universe,sapply(x,function(i) lines(c(i,i),c(lower[i],upper[i]))))
}
\keyword{datasets}

\eof
\name{alaska.pipeline}
\alias{alaska.pipeline}
\docType{data}
\title{Comparison of in-field and laboratory measurement of defects }
\description{
   The Alaska pipeline data consists of in-field ultrasonic measurements
   of the depths of defects in the Alaska pipeline. The depth of the
   defects were then re-measured in the laboratory. These measurements
   were performed in six different batches.
}
\usage{data(alaska.pipeline)}
\format{
  A data frame with 107 observations on the following 3 variables.
  \describe{
    \item{field.defect}{Depth of defect as measured in field}
    \item{lab.defect}{Depth of defect as measured in lab}
    \item{batch}{One of 6 batches}
  }
}
\source{
    From an example in \emph{Engineering Statistics Handbook} from \url{http://www.itl.nist.gov/div898/handbook/}
}
\examples{
data(alaska.pipeline)
res = lm(lab.defect ~ field.defect, alaska.pipeline)
plot(lab.defect ~ field.defect, alaska.pipeline)
abline(res)
plot(fitted(res),resid(res))
}
\keyword{datasets}

\eof
\name{alltime.movies}
\alias{alltime.movies}
\docType{data}
\title{Top movies of all time}
\description{
  The top 79 all-time movies as of 2003 by domestic (US) gross receipts.
}
\usage{data(alltime.movies)}
\format{
  A data frame with 79 observations on the following 2 variables.
  \describe{
    \item{Gross}{a numeric vector}
    \item{Release.Year}{a numeric vector}
  }
  The row names are the titles of the movies.
}
\source{
  This data was found on \url{http://movieweb.com/movie/alltime.html} on
  June 17, 2003. The source of the data is attributed to (partially)
  Exhibitor Relations Co. .
}
\examples{
data(alltime.movies)
hist(alltime.movies$Gross)
}
\keyword{datasets}

\eof
\name{babies}
\alias{babies}
\docType{data}
\title{Mothers and their babies data}
\description{
  A collection of variables taken for each new mother in a Child and
  Health Development Study.
}
\usage{data(babies)}
\format{
  A data frame with 1,236 observations on the following 23 variables.
  \describe{
    Variables in data file
    \item{id}{identification number}
    \item{pluralty}{ 5= single fetus}
    \item{outcome}{1= live birth that survived at least 28 days}
    \item{date}{birth date where 1096=January1,1961 }
    \item{gestation}{length of gestation in days}
    \item{sex}{infant's sex 1=male 2=female 9=unknown}
    \item{wt}{ birth weight in ounces (999 unknown)}
    \item{parity}{total number of previous pregnancies including
      fetal deaths and still births, 99=unknown}
    \item{race}{mother's race 0-5=white 6=mex 7=black 8=asian 9=mixed 99=unknown }
    \item{age}{mother's age in years at termination of pregnancy, 99=unknown}
    \item{ed}{mother's education 0= less than 8th grade, 
      1 = 8th -12th grade - did not graduate, 
      2= HS graduate--no other schooling , 3= HS+trade,
      4=HS+some college 5= College graduate, 6\&7 Trade school HS
      unclear, 9=unknown
    }
    \item{ht}{mother's height in inches to the last completed inch
      99=unknown}
    \item{wt1}{mother prepregnancy wt in pounds, 999=unknown }
    \item{drace}{father's race, coding same as mother's race.}
    \item{dage}{father's age, coding same as mother's age.}
    \item{ded }{father's education, coding same as mother's education.}
    \item{dht}{father's height, coding same as for mother's height}
    \item{dwt }{father's weight coding same as for mother's weight}
    \item{marital}{ 1=married, 2= legally separated, 3= divorced,
      4=widowed, 5=never married}
    \item{inc}{family yearly income in \$2500 increments 0 = under 2500,
      1=2500-4999, ..., 8= 12,500-14,999, 9=15000+,
      98=unknown, 99=not asked}
    \item{smoke}{does mother smoke? 0=never, 1= smokes now, 
      2=until current pregnancy, 3=once did, not now, 9=unknown}
    \item{time}{If mother quit, how long ago? 0=never smoked, 1=still smokes,
      2=during current preg, 3=within 1 yr, 4= 1 to 2 years ago,
      5= 2 to 3 yr ago, 6= 3 to 4 yrs ago, 7=5 to 9yrs ago, 
      8=10+yrs ago, 9=quit and don't know, 98=unknown, 99=not asked }
    \item{number }{number of cigs smoked per day for past and current
      smokers 0=never, 1=1-4,2=5-9, 3=10-14, 4=15-19, 5=20-29, 6=30-39,
      7=40-60, 8=60+, 9=smoke but don't know,98=unknown, 99=not asked}
  }
}
\source{
  This dataset is found from
  \url{http://www.stat.berkeley.edu/users/statlabs/labs.html}. It
  accompanies the excellent text \emph{Stat Labs: Mathematical
  Statistics through Applications} Springer-Verlag (2001) by Deborah
  Nolan and Terry Speed.
}
\examples{
data(babies)
plot(wt ~ factor(smoke), data=babies)
plot(wt1 ~ dwt, data=babies, subset=wt1 < 800 & dwt < 800)
}
\keyword{datasets}

\eof
\name{babyboom}
\alias{babyboom}
\docType{data}
\title{Babyboom: data for 44 babies born in one 24-hour period.}
\description{
  The \code{babyboom} dataset contains the time of birth, sex, and birth
  weight for 44 babies born in one 24-hour period at a hospital in
  Brisbane, Australia.
} 
\usage{data(babyboom)}
\format{
  A data frame with 44 observations on the following 4 variables.
  \describe{
    \item{clock.time}{Time on clock}
    \item{gender}{a factor with levels \code{girl} \code{boy}}
    \item{wt}{weight in grams of child}
    \item{running.time}{minutes after midnight of birth}
  }
}
\source{
  This data set was submitted to the \emph{Journal of Statistical
  Education},
  \url{http://www.amstat.org/publications/jse/secure/v7n3/datasets.dunn.cfm},
  by Peter K. Dunn.
}
\examples{
data(babyboom)
hist(babyboom$wt)
hist(diff(babyboom$running.time))
}
\keyword{datasets}

\eof
\name{batting}
\alias{batting}
\docType{data}
\title{ Batting statistics for 2002 baseball season}
\description{
  This dataset contains batting statistics for the 2002 baseball
  season. The data allows you to compute batting averages, on base
  percentages, and other statistics of interest to baseball fans. The
  data only contains players with more than 100 atbats for a team in the
  year. The data is excerpted with permission from the Lahman baseball
  database at \url{http://www.baseball1.com/}.

}
\usage{data(batting)}
\format{
  A data frame with 438 observations on the following 22 variables.
  \describe{
    \item{playerID}{This is coded, but those familiar with the players
    should be able to find their favorites.}
    \item{yearID}{a numeric vector. Always 2002 in this dataset.}
    \item{stintID}{a numeric vector. Player's stint (order of appearances within a season)}
    \item{teamID}{a factor with Team}
    \item{lgID}{a factor with levels \code{AL} \code{NL}}
    \item{G}{number of games played}
    \item{AB}{number of at bats}
    \item{R}{number of runs}
    \item{H}{number of hits}
    \item{DOUBLE}{number of doubles. "2B" in original dat
  a base.}
    \item{TRIPLE}{number of triples. "3B" in original data base}
    \item{HR}{number of home runs}
    \item{RBI}{number of runs batted in}
    \item{SB}{number of stolen bases}
    \item{CS}{number of times caught stealing}
    \item{BB}{number of base on balls (walks)}
    \item{SO}{number of strikeouts}
    \item{IBB}{number of intentional walks}
    \item{HBP}{number of hit by pitches}
    \item{SH}{number of sacrifice hits}
    \item{SF}{number of sacrifice flies}
    \item{GIDP}{number of grounded into double plays}
  }
}
\details{
  Baseball fans are \dQuote{statistics} crazy. They love to talk about things
  like RBIs, BAs and OBPs. In order to do so, they need the
  numbers. This data comes from the Lahman baseball
  database at \url{http://www.baseball1.com/}. The complete dataset
  includes data for all of baseball not just the year 2002 presented here.

}
\source{
   Lahman baseball database, \url{http://www.baseball1.com/}
}
\references{
  In addition to the data set above, the book
  \emph{Curve Ball}, by Albert, J. and Bennett, J., Copernicus Books,
  gives an extensive statistical analysis of baseball.

  See \url{http://www.baseball-almanac.com/stats.shtml} for definitions
  of common baseball statistics.
}
\examples{
data(batting)
attach(batting)
BA = H/AB			# batting average
OBP = (H + BB + HBP) / (AB + BB + HBP + SF) # On base "percentage"
}
\keyword{datasets}

\eof
\name{baycheck}
\alias{baycheck}
\docType{data}
\title{ Population estimate of type of Bay Checkerspot butterfly}
\description{
  Estimates of the population of a type of Bay Checkerspot butterfly
  near San Francisco.
}
\usage{data(baycheck)}
\format{
  A data frame with 27 observations on the following 2 variables.
  \describe{
    \item{year}{a numeric vector}
    \item{Nt}{estimated number}
  }
}
\source{
  From chapter 4 of Morris and Doak, \emph{Quantitative Conservation
  Biology: Theory and Practice of Population Viability Analysis},
  Sinauer Associates, 2003.
}
\examples{
data(baycheck)
plot(Nt ~ year,baycheck)
## fit Ricker model N_{t+1} = N_t e^{-rt}W_t
n = length(baycheck$year)
yt = with(baycheck,log(Nt[-1]/Nt[-n]))
nt = with(baycheck,Nt[-n])
lm(yt ~ nt,baycheck)
}
\keyword{datasets}

\eof
\name{best.times}
\alias{best.times}
\docType{data}
\title{ Best track and field times by age and distance}
\description{
  A dataset giving world records in track and field running events for various
  distances and different age groups.
}
\usage{data(best.times)}
\format{
  A data frame with 113 observations on the following 6 variables.
  \describe{
    \item{Dist}{Distance in meters (42195 is a marathon)}
    \item{Name}{Name of record holder}
    \item{Date}{Date of record}
    \item{Time}{Time in seconds}
    \item{Time.1}{Time as character}
    \item{age}{Age at time of record}
  }
}
\details{
  Age-graded race results allow competitors of different ages to compare
  their race performances. This data set allows one to see what the
  relationship is based on peak performances.  
}
\source{
  The data comes from
  \url{http://www.personal.rdg.ac.uk/~snsgrubb/athletics/agegroups.html}
  which includes a calculator to compare results.
  
}
\examples{
data(best.times)
attach(best.times)
by.dist = split(best.times,as.factor(Dist))
lm(scale(Time) ~ age, by.dist[['400']])
dists = names(by.dist)
lapply(dists, function(n) print(lm(scale(Time) ~ age, by.dist[[n]])))
}
\keyword{datasets}

\eof
\name{breakdown}
\alias{breakdown}
\docType{data}
\title{ Time of insulating fluid to breakdown}
\description{
  The time in minutes for an insulating fluid to break down under
  varying voltage loads
}
\usage{data(breakdown)}
\format{
  A data frame with 75 observations on the following 2 variables.
  \describe{
    \item{voltage}{Number of kV}
    \item{time}{time in minutes}
  }
}
\details{
  An example from industry where a linear model is used with replication
  and transformation of variables.
}
\source{
  Data is from Display 8.3 of Ramsay and Shafer, \emph{The Statistical
  Sleuth} Duxbury Press, 1997.
}
\examples{
data(breakdown)
plot(log(time) ~ voltage, data = breakdown)
}
\keyword{datasets}

\eof
\name{bright.stars}
\alias{bright.stars}
\docType{data}
\title{ List of bright stars with Hipparcos catalog number}
\description{
  List of bright stars with Hipparcos catalog number.
}
\usage{data(bright.stars)}
\format{
  A data frame with 96 observations on the following 2 variables.
  \describe{
    \item{name}{Common name of star}
    \item{hip}{HIP number for identification}
  }
}
\details{
  The source of star names goes back to the Greeks and Arabs. Few are
  modern. This is a list of 96 common stars.
}
\source{
  Form the Hipparcos website \url{http://astro.estec.esa.nl/Hipparcos/ident6.html}.
}
\examples{
data(bright.stars)
all.names  = paste(bright.stars$name, sep="", collapse="")
x = unlist(strsplit(tolower(all.names), ""))
letter.dist = sapply(letters, function(i) sum(x == i))
data(scrabble)			#  for frequency info
p = scrabble$frequency[1:26];p=p/sum(p)
chisq.test(letter.dist, p=p)	# compare with English
}
\keyword{datasets}

\eof
\name{brightness}
\alias{brightness}
\docType{data}
\title{Brightness of 966 stars}
\description{
  The Hipparcos Catalogue has information on over 100,000 stars. Listed
  in this dataset are brightness measurements for 966 stars from a given
  sector of the sky.
}
\usage{data(brightness)}
\format{
  A univariate dataset of 966 numbers.
}
\details{
  This is field H5 in the catalog measuring the magnitude, V , in the
  Johnson UBV photometric system. The smaller numbers are for brighter stars.
}
\source{
  \url{http://astro.estec.esa.nl/hipparcos}
}
\examples{
data(brightness)
hist(brightness)
}
\keyword{datasets}

\eof
\name{bumpers}
\alias{bumpers}
\non_function{}
\title{ Bumper repair costs for various automobiles}
\description{ bumper repair costs }
\usage{data(bumpers)}
\format{
  Price in dollars to repair a bumper.
}
\source{
  From \emph{Exploring Statistics}, Duxbury Press, 1998, L. Kitchens.
}
\examples{
data(bumpers)
stem(bumpers)
}
\keyword{datasets}

\eof
\name{bycatch}
\alias{bycatch}
\docType{data}
\title{Number of Albatrosses accidentaly caught during a fishing haul}
\description{
  This data set from Hillborn and Mangel contains data on the number of
  Albatrosses accidentally caught while fishing by commercial
  fisheries. 
}
\usage{data(bycatch)}
\format{
  A data frame with 18 observations on the following 2 variables.
  \describe{
    \item{no.albatross}{The number of albatross caught}
    \item{no.hauls}{Number of hauls with this many albatross caught}
  }
}
\details{
  During fishing operations non-target species are often captured. These
  are called \dQuote{incidental catch}. In some cases, large-scale observer
  programs are used to monitor this incidental catch.

  When fishing for squid, albatrosses are caught while feeding on the
  squid at the time of fising. This feeding is encouraged while the net
  is being hauled in, as the squid are clustered making it  an opportunistic
  time for the albatross to eat.
}
\source{
  This is from Hilborn and Mangel, \emph{The Ecological Detective},
  Princeton University Press, 1997. Original source of data is Bartle.
}
\examples{
data(bycatch)
hauls = with(bycatch,rep(no.albatross,no.hauls))
}
\keyword{datasets}

\eof
\name{cabinet}
\alias{cabinet}
\docType{data}
\title{Estimated tax savings for US President Bush's cabinet}
\description{
  Estimated savings from a repeal of the tax on capital gains and
  dividends for Bush's cabinet members.
}
\usage{data(cabinet)}
\format{
  A data frame with 19 observations on the following 4 variables.
  \describe{
    \item{name}{Name of individual}
    \item{position}{Position of individual}
    \item{est.dividend.cg}{Estimated amount of dividend and capital gain
    income}
    \item{est.tax.savings}{Estimated tax savings}
  }
}
\details{
Quoting from the data source
  \url{http://www.house.gov/reform/min/pdfs_108/pdf_inves/pdf_admin_tax_law_cabinet_june_3_rep.pdf} (From Henry Waxman, congressional watchdog.)
  
  \dQuote{On May 22, 2003, the House of Representatives and the Senate passed
  tax legislation that included \$320 billion in tax cuts. The final tax
  cut bill was signed into law by President Bush on May 28, 2003. The
  largest component of the new tax law is the reduction of tax rates on
  both capital gains and dividend income. The law also includes the
  acceleration of future tax cuts, as well as new tax reductions for
  businesses.

  This capital gains and dividend tax cut will have virtually no impact
  on the average American. The vast majority of Americans (88%) report
  no capital gains on their tax returns. These taxpayers will receive
  no tax savings at all from the reduction in taxes on capital
  gains. Similarly, most Americans (75%) will receive no tax savings
  from the reduction of taxes on dividends.


  While the average American will derive little, if any, benefit from the
  cuts in dividend and capital gains taxes, the law offers significant
  benefits to the wealthy. For example, the top 1% of taxpayers will
  receive an average tax cut of almost \$21,000 each. In particular, some
  of the major beneficiaries of this plan will be Vice President Cheney,
  President Bush, and other members of the cabinet. Based on 2001 and 2002
  dividends and capital gains income, Vice President Cheney, President
  Bush, and the cabinet are estimated to receive an average tax cut of at
  least \$42,000 per year. Their average tax savings equals the median
  household income in the United States.}


  }

\source{
  \url{http://www.house.gov/reform/min/pdfs_108/pdf_inves/pdf_admin_tax_law_cabinet_june_3_rep.pdf} 
}
\examples{
data(cabinet)
attach(cabinet)
median(est.dividend.cg)
mean(est.dividend.cg)
detach(cabinet)
}
\keyword{datasets}

\eof
\name{cancer}
\alias{cancer}
\non_function{}
\title{ cancer survival times  }
\description{ cancer survival times }
\usage{data(cancer)}
\format{
  The format is:
  a list with  5 components
 \item{stomach:}{ num [1:13] 124  42  25  45 412 ...}
 \item{bronchus:}{ num [1:17] 81 461 20 450 246 166 63 64 155 859 ...}
 \item{colon   :}{ num [1:17]  248  377  189 1843  180 ...}
 \item{ovary   : }{num [1:6] 1234   89  201  356 2970 ...}
 \item{breast  :}{ num [1:11] 1235   24 1581 1166   40 ...}
}
\source{
  Taken  from L. Kitchens, \emph{Exploring Statistics}, Duxbury Press, 1997.
}
\examples{
data(cancer)
boxplot(cancer)
}
\keyword{datasets}

\eof
\name{carsafety}
\alias{carsafety}
\docType{data}
\title{Fatality information in U.S. for several popular cars}
\description{
  Safety statistics appearing in a January 12th, 2004 issue of the \emph{New
  Yorker}  showing fatality rates per million vehicles both for
  drivers of a car, and drivers of other cars that are hit.
}
\usage{data(carsafety)}
\format{
  A data frame with 33 observations on the following 4 variables.
  \describe{
    \item{Make.model}{The make and model of the car}
    \item{type}{Type of car}
    \item{Driver.deaths}{Number of drivers deaths per year if 1,000,000 cars
    were on the road}

  \item{Other.deaths}{Number of deaths in other vehicle caused by
    accidents involving
    these cars per year if 1,000,000 cars were on the road}
  }
}
\details{
  The article this data came from wishes to make the case that SUVs are
  not safer despite a perception among the U.S. public that they are.
}
\source{
  From "Big and Bad" by Malcolm Gladwell. \emph{New Yorker}, Jan. 12 2004
  pp28-33. Data attributed to Tom Wenzel and Marc Ross who have written
  \url{http://www.lbl.gov/Science-Articles/Archive/assets/images/2002/Aug-26-2002/SUV-report.pdf}. 
}
\examples{
data(carsafety)
plot(Driver.deaths + Other.deaths ~ type, data = carsafety)
plot(Driver.deaths + Other.deaths ~ type, data = carsafety)
}
\keyword{datasets}

\eof
\name{central.park}
\alias{central.park}
\docType{data}
\title{Weather in Central Park NY in May 2003}
\description{
  A listing of various weather measurements made at Central Park in New
  York City during the month of May 2003.
}
\usage{data(central.park)}
\format{
  A data frame with 31 observations on the following 19 variables.
  \describe{
    \item{DY}{the day}
    \item{MAX}{maximum temperature (temperatures in Farenheit)}
    \item{MIN}{minimum temperature}
    \item{AVG}{average temperature}
    \item{DEP}{departure from normal}
    \item{HDD}{heating degree days}
    \item{CDD}{cooling degree days}
    \item{WTR}{Water fall. A factor as "T" is a trace.}
    \item{SNW}{Amount of snowfall}
    \item{DPTH}{Depth of snow}
    \item{SPD}{Average wind speed}
    \item{SPD1}{Max wind speed}
    \item{DIR}{2 minimum direction}
    \item{MIN2}{Sunshine measurement a factor with two levels \code{0} \code{M}}
    \item{PSBL}{Sunshine measurement a factor with levels \code{0} \code{M}}
    \item{S.S}{Sunshine measurement. 0-3 = Clear, 4-7 partly cloudy,
    8-10 is cloudy}
    \item{WX}{1 = FOG,
2 = FOG REDUCING VISIBILITY  
    TO 1/4 MILE OR LESS,      
3 = THUNDER,                  
4 = ICE PELLETS,              
5 = HAIL,                     
6 = GLAZE OR RIME,
7 = BLOWING DUST OR SAND:    
    VSBY 1/2 MILE OR LESS,    
8 = SMOKE OR HAZE,            
9 = BLOWING SNOW,             
X = TORNADO
}
    \item{SPD3}{peak wind speed}
    \item{DR}{direction of peak wind}
  }
  }
\details{
  This datasets summarizes the weather in New York City during the merry
  month of May 2003.  This data set comes from the daily climate report
  issued by the National Weather Service Office.  
}
\source{
  This data is published
  by \url{http://www.noah.gov}.
}
\examples{
data(central.park)
attach(central.park)
barplot(rbind(MIN,MAX-MIN),ylim=c(0,80))
}
\keyword{datasets}

\eof
\name{central.park.cloud}
\alias{central.park.cloud}
\docType{data}
\title{ Type of day in Central Park, NY May 2003}
\description{
  The type of day in May 2003 in Central Park, NY
}
\usage{data(central.park.cloud)}
\format{
  A factor with levels \code{clear},\code{partly.cloudy} and \code{cloudy}.
}
\source{
  This type of data, and much more, is available from
  \url{http://www.noaa.gov}.
}
\examples{
data(central.park.cloud)
table(central.park.cloud)
}
\keyword{datasets}

\eof
\name{cfb}
\alias{cfb}
\docType{data}
\title{ Bootstrap sample from the Survey of Consumer Finances}
\description{
  A bootstrap sample from the \dQuote{Survey of Consumer Finances}.
}
\usage{data(cfb)}
\format{
  A data frame with 1000 observations on the following 14
  variables. 
  \describe{
    \item{WGT}{Weights to comensate for undersampling. Not applicable}
    \item{AGE}{Age of participants}
    \item{EDUC}{Education level (number of years) of participant}
    \item{INCOME}{Income in year 2001 of participant}
    \item{CHECKING}{Amount in checking account for participant}
    \item{SAVING}{Amount in savings accounts}
    \item{NMMF}{Total directly-held mutual funds}
    \item{STOCKS}{Amount held in stocks}
    \item{FIN}{Total financial assets}
    \item{VEHIC}{Value of all vehicles (includes autos, motor homes, RVs, airplanes,
      boats)}
    \item{HOMEEQ}{Total home equity}
    \item{OTHNFIN}{Other financial assets}
    \item{DEBT}{Total debt}
    \item{NETWORTH}{Total net worth}
  }

}
\details{
  The SCF dataset is a comprehensive survey of consumer finances
  sponsored by the United States Federal Reserve,
  \url{http://www.federalreserve.gov/pubs/oss/oss2/2001/scf2001home.html}. 

  The data is oversampled to compensate for low response in the upper
  brackets. To compensate, weights are assigned. By bootstrapping the
  data with the weights, we get a \dQuote{better} version of a random sample
  from the population.
}
\source{
  \url{http://www.federalreserve.gov/pubs/oss/oss2/2001/scf2001home.html}
}
\examples{
data(cfb)
attach(cfb)
mean(INCOME)
}
\keyword{datasets}

\eof
\name{coins}
\alias{coins}
\docType{data}
\title{The coins in my change bin}
\description{
  The coins in author's change bin with year and value.
}
\usage{data(coins)}
\format{
  A data frame with 371 observations on the following 2 variables.
  \describe{
    \item{year}{Year of coin}
    \item{value}{Value of coin: quarter, dime, nickel, or penny}
  }
}
\examples{
data(coins)
years = cut(coins$year,seq(1920,2010,by=10),include.lowest=TRUE,
  labels = paste(192:200,"*",sep=""))
table(years)
}
\keyword{datasets}

\eof
\name{deflection}
\alias{deflection}
\docType{data}
\title{ Deflection under load}
\description{
  The data collected in a calibration experiment consisting of a known
  load, applied to the load cell, and the corresponding deflection of
  the cell from its nominal position.
}
\usage{data(deflection)}
\format{
  A data frame with 40 observations on the following 2 variables.
  \describe{
    \item{Deflection}{a numeric vector}
    \item{Load}{a numeric vector}
  }
}
\source{
  From an example in \emph{Engineering Statistics Handbook} from \url{http://www.itl.nist.gov/div898/handbook/}
}
\examples{
data(deflection)
res = lm(Deflection ~ Load, data = deflection)
plot(Deflection ~ Load, data = deflection)
abline(res)			# looks good?
plot(res)
}
\keyword{datasets}

\eof
\name{diamond}
\alias{diamond}
\docType{data}
\title{Price by size for diamond rings}
\description{
  A data set on 48 diamond rings containing price in Singapore dollars
  and size of diamond in carats.
}
\usage{data(diamond)}
\format{
  A data frame with 48 observations on the following 2 variables.
  \describe{
    \item{carat}{A measurement of a diamond's size}
    \item{price}{Price in Singapore dollars}
  }
}
\details{
  This data comes from a collection of the \emph{Journal of Statistics
  Education}. The accompanying documentation says:
  
\dQuote{Data presented in a newspaper advertisement suggest the use of simple
linear regression to relate the prices of diamond rings to the weights
of their diamond stones.  The intercept of the resulting regression line
is negative and significantly different from zero.  This finding raises
questions about an assumed pricing mechanism and motivates consideration
of remedial actions.}

}
\source{
  This comes from
  \url{http://www.amstat.org/publications/jse/datasets/diamond.txt}. Data
  set is contributed by Singfat Chu.
}
\examples{
data(diamond)
plot(price ~ carat, diamond, pch=5)
}
\keyword{datasets}

\eof
\name{dottodot}
\alias{dottodot}
\docType{data}
\title{Dot-to-dot puzzle}
\description{
  A set of points to make a dot-to-dot puzzle
}
\usage{data(dottodot)}
\format{
  A data frame with 49 observations on the following 4 variables.
  \describe{
    \item{x}{x position}
    \item{y}{y position}
    \item{pos}{where to put label}
    \item{ind}{number for label}
  }
}
\details{
  Points to make a dot to dot puzzle to illustrate,
  \code{\link{text}}, \code{\link{points}}, and the argument \code{pos}.
}
\source{
  Illustration by Noah Verzani.
}
\examples{
data(dottodot)
# make a blank graph
plot(y~x,data=dottodot,type="n",bty="n",xaxt="n",xlab="",yaxt="n",ylab="")
# add the points
points(y~x,data=dottodot)
# add the labels using pos argument
with(dottodot, text(x,y,labels=ind,pos=pos))
# solve the puzzle
lines(y~x, data=dottodot)
}
\keyword{datasets}

\eof
\name{dvdsales}
\alias{dvdsales}
\docType{data}
\title{Monthly DVD player sales since introduction to May 2004}
\description{
  Monthly DVD player sales since introduction of DVD format to May 2004
}
\usage{data(dvdsales)}
\format{
  Matrix with rows recording the year, and columns the month.
}
\source{
  \url{http://www.thedigitalbits.com/articles/cemadvdsales.html}
}
\examples{
data(dvdsales)
barplot(t(dvdsales[7:1,]),beside=TRUE)
}
\keyword{datasets}

\eof
\name{emissions}
\alias{emissions}
\non_function{}
\title{ CO2 emissions data and gross domestic product for 26 countries}
\usage{data(emissions)}
\description{
The \code{emissions} data frame has 26 rows and 3 columns.

A data set listing GDP, GDP per capita, and CO2 emissions for 1999.  }
\format{
  This data frame contains the following columns:
  \describe{
    \item{GDP}{a numeric vector}
    \item{perCapita}{a numeric vector}
    \item{CO2}{a numeric vector}
  }
}
\source{
  \url{http://www.grida.no} for CO2 data and
  \url{http://www.mrdowling.com} for GDP data.

  Prompted by a plot appearing in a June 2001 issue of the \emph{New
  York Times}.

}
\examples{
data(emissions)
plot(emissions)
}
\keyword{datasets}

\eof
\name{ewr}
\alias{ewr}
\non_function{}
\title{ Taxi in and taxi out times at EWR (Newark) airport for 1999-2001 }
\usage{data(ewr)}
\description{
  The \code{ewr} data frame has 46 rows and 11 columns.

  Gives taxi in and taxi out times for 8 different airlines and several
  months at EWR airport.

  Airline codes are
  \code{AA} (American Airlines),
  \code{AQ} (Aloha Airlines),
  \code{AS} (Alaska Airlines),
  \code{CO} (Continental Airlines),
  \code{DL} (Delta Airlines),
  \code{HP} (America West Airlines),
  \code{NW} (Northwest Airlines),
  \code{TW} (Trans World Airlines),
  \code{UA} (United Airlines),
  \code{US} (US Airways), and
  \code{WN} (Southwest Airlines)
  
}
\format{
  This data frame contains the following columns:
  \describe{
    \item{Year}{a numeric vector}
    \item{Month}{a factor for months}
    \item{AA}{a numeric vector}
    \item{CO}{a numeric vector}
    \item{DL}{a numeric vector}
    \item{HP}{a numeric vector}
    \item{NW}{a numeric vector}
    \item{TW}{a numeric vector}
    \item{UA}{a numeric vector}
    \item{US}{a numeric vector}
    \item{inorout}{a factor with levels \code{in} or \code{out} }
  }
}
\source{
  \url{http://www.bts.gov/oai/taxitime/html/ewrtaxi.html}
}
\examples{
data(ewr)
boxplot(ewr[3:10])
}
\keyword{datasets}

\eof
\name{exec.pay}
\alias{exec.pay}
\non_function{}
\title{ Direct compensation for 199 United States CEOs in the year 2000  }
\description{ Direct compensation for 199 United States CEOs in the year 2000
in units of \$10,000.  }
\usage{data(exec.pay)}
\format{
  A numeric vector with 199 entries each measuring compensation in 10,000s
  of dollars.
}
\source{
\emph{New York Times} Business section 04/01/2001. See also \url{http://www.aflcio.org}.
}
\examples{
data(exec.pay)
hist(exec.pay)
}
\keyword{datasets}

\eof
\name{fat}
\alias{fat}
\docType{data}
\title{Body measurements to predict percentage of body fat in males}
\description{
  A data set containing many physical measurements of 252 males. Most of
  the variables can be measured with a scale or tape measure. Can they
  be used to predict the percentage of body fat? If so, this offers an
  easy alternative to an underwater weighing technique.
}
\usage{data(fat)}
\format{
  A data frame with 252 observations on the following 19 variables.
  \describe{
    \item{case}{Case Number}
    \item{body.fat}{Percent body fat using Brozek's equation, 
           457/Density - 414.2}
    \item{body.fat.siri}{Percent body fat using Siri's equation, 
           495/Density - 450}
    \item{density}{Density (gm/cm\eqn{\mbox{\textasciicircum}}{\^}2)}
    \item{age}{Age (yrs)}
    \item{weight}{Weight (lbs)}
    \item{height}{Height (inches)}
    \item{BMI}{Adiposity index = Weight/Height\eqn{\mbox{\textasciicircum}}{^}2 (kg/m\eqn{\mbox{\textasciicircum}}{^}2)}
    \item{ffweight}{Fat Free Weight 
           = (1 - fraction of body fat) * Weight,            using Brozek's formula (lbs)}
    \item{neck}{Neck circumference (cm)}
    \item{chest}{Chest circumference (cm)}
    \item{abdomen}{Abdomen circumference (cm) "at the umbilicus 
           and level with the iliac crest"}
    \item{hip}{Hip circumference (cm)}
    \item{thigh}{Thigh circumference (cm)}
    \item{knee}{Knee circumference (cm)}
    \item{ankle}{Ankle circumference (cm)}
    \item{bicep}{Extended biceps circumference (cm)}
    \item{forearm}{Forearm circumference (cm)}
    \item{wrist}{Wrist circumference (cm) "distal to the 
           styloid processes"}
  }
}

\details{
From the source:
  
\dQuote{The data are as received from Dr. Fisher.  Note, however, that there
are a few errors.  The body densities for cases 48, 76, and 96, for
instance, each seem to have one digit in error as can be seen from the
two body fat percentage values.  Also note the presence of a man (case
42) over 200 pounds in weight who is less than 3 feet tall (the height
should presumably be 69.5 inches, not 29.5 inches)!  The percent body
fat estimates are truncated to zero when negative (case 182).}
}

\source{
  This data set comes from the collection of the \emph{Journal of
  Statistics Education} at
  \url{http://www.amstat.org/publications/jse/datasets/fat.txt}. The
  data set was contributed by Roger W. Johnson.
}
\references{
  The source of the data is attributed to Dr. A. Garth Fisher, Human
Performance Research Center, Brigham Young University, Provo, Utah
84602, 
}

\examples{
data(fat)
f = body.fat ~ age + weight + height + BMI + neck + chest + abdomen +
hip + thigh + knee + ankle + bicep + forearm + wrist
res = lm(f, data=fat)
summary(res)
}
\keyword{datasets}

\eof
\name{father.son}
\alias{father.son}
\docType{data}
\title{Galton's data set on heights of  fathers and their sons}
\description{
  1078 measurements of a father's height and his son's height.
}
\usage{data(father.son)}
\format{
  A data frame with 1078 observations on the following 2 variables.
  \describe{
    \item{fheight}{Father's height in inches}
    \item{sheight}{Son's height in inches}
  }
}
\details{
  Data set used by Galton to investigate regression.
}
\source{
  Read into R by the command
  
  \code{read.table("http://stat-www.berkeley.edu/users/juliab/141C/pearson.dat",sep=" ")[,-1]},

  as mentioned by Chuck Cleland on the r-help mailing list.
}
\examples{
data(father.son)
## like cover of Freedman, Pisani, and Purves
plot(sheight ~ fheight, data=father.son,bty="l",pch=20)
abline(a=0,b=1,lty=2,lwd=2)
abline(lm(sheight ~ fheight, data=father.son),lty=1,lwd=2)
}
\keyword{datasets}

\eof
\name{female.inc}
\alias{female.inc}
\docType{data}
\title{ Income distribution for females in 2001}
\description{
  A data set containing incomes for 1,000 females along with race
  information. The data is sampled from data provided by the United
  States Census Bureau.
}
\usage{data(female.inc)}
\format{
  A data frame with 1,000 observations on the following 2 variables.
  \describe{
    \item{income}{Income for 2001 in dollars}
    \item{race}{a factor with levels \code{black}, \code{hispanic} or \code{white}}
  }
}
\details{
  The United States Census Bureau provides alot of data on income
  distributions. This data comes from the Current Population Survey
  (CPS) for the year 2001. The raw data appears in  table format. This
  data is sampled from the data in that table.
}
\source{
  The original table is found at
  \url{http://ferret.bls.census.gov/macro/032002/perinc/new11_002.htm}. 
}
\examples{
data(female.inc)
boxplot(income ~ race, female.inc)
boxplot(log(income,10) ~ race, female.inc)
sapply(with(female.inc,split(income,race)),median)
}
\keyword{datasets}

\eof
\name{firstchi}
\alias{firstchi}
\non_function{}
\title{Age of mother at birth of first child }
\description{Age of mother at birth of first child }
\usage{data(firstchi)}
\format{
  The format is:
 num [1:87] 30 18 35 22 23 22 36 24 23 28 ...
}
\source{
  From \emph{Exploring Statistics},  L. Kitchens, Duxbury Press, 1998.
}
\examples{
data(firstchi)
hist(firstchi)
}
\keyword{datasets}

\eof
\name{five.yr.temperature}
\alias{five.yr.temperature}
\docType{data}
\title{ Five years of weather in New York City}
\description{
  Five years of maximum temperatures in New York City
}
\usage{data(five.yr.temperatures)}
\format{
  A data frame with 2,439 observations on the following 3 variables.
  \describe{
    \item{days}{Which day of the year}
    \item{years}{The year}
    \item{temps}{Maximum temperature}
  }
}
\source{
  Dataset found on the internet, but original source is lost.
}
\examples{
data(five.yr.temperature)
attach(five.yr.temperature)
scatter.smooth(temps ~ days,col=gray(.75))
lines(smooth.spline(temps ~ days), lty=2)
lines(supsmu(days, temps), lty=3)
}
\keyword{datasets}

\eof
\name{florida}
\alias{florida}
\non_function{}
\title{ County-by-county results of year 2000 US presidential election
in Florida }
\usage{data(florida)}
\description{
The \code{florida} data frame has 67 rows and 13 columns.

Gives a county by county accounting of the US elections in the state of
Florida.  }
\format{
  This data frame contains the following columns:
  \describe{
    \item{County}{Name of county}
    \item{GORE}{Votes for Gore}
    \item{BUSH}{Votes for Bush}
    \item{BUCHANAN}{Votes for Buchanan}
    \item{NADER}{Votes for Nader}
    \item{BROWN}{a numeric vector}
    \item{HAGELIN}{a numeric vector}
    \item{HARRIS}{a numeric vector}
    \item{MCREYNOLDS}{a numeric vector}
    \item{MOOREHEAD}{a numeric vector}
    \item{PHILLIPS}{a numeric vector}
    \item{Total}{a numeric vector}
  }
}
\source{
  Found in the excellent notes \emph{Using R for Data Analysis and
  Graphics} by John Maindonald. (As of 2003 a book published by
  Cambridge University Press.)
}
\examples{
data(florida)
attach(florida)
result.lm <- lm(BUCHANAN ~ BUSH)
plot(BUSH,BUCHANAN)
abline(result.lm) ## can you find Palm Beach and Miami Dade counties?
}
\keyword{datasets}

\eof
\name{galileo}
\alias{galileo}
\docType{data}
\title{ Galileo data on falling bodies}
\description{
  Data recorded by Galileo in 1609 during his investigations of the
  trajectory of a falling body.
}
\usage{data(galileo)}
\format{
  A data frame with 7 observations on the following 2 variables.
  \describe{
    \item{init.h}{Initial height of ball}
    \item{h.d}{Horizontal distance traveled}
  }
}
\details{
  A simple ramp 500 punti above the ground was constructed. A ball was
  placed on the ramp at an indicated height from the ground and
  released. The horizontal distance traveled is recorded (in
  punti). (One punto is 169/180 millimeter, not a car by FIAT.)
}
\source{
  This data and example come from the \emph{Statistical Sleuth} by
  Ramsay and Schafer, Duxbury (2001), section 10.1.1. They attribute an
  article in \emph{Scientific American} by
  Drake and MacLachlan.
}
\examples{
data(galileo)
polynomial = function(x,coefs) {
  sum = 0
  for(i in 0:(length(coefs)-1)) {
    sum = sum + coefs[i+1]*x^i
  }
  sum
}
res.lm = lm(h.d ~ init.h, data = galileo)
res.lm2 = update(res.lm, . ~ . + I(init.h^2), data=galileo)
res.lm3 = update(res.lm2, . ~ . + I(init.h^3), data=galileo)
plot(h.d ~ init.h, data = galileo)
curve(polynomial(x,coef(res.lm)),add=TRUE)
curve(polynomial(x,coef(res.lm2)),add=TRUE)
curve(polynomial(x,coef(res.lm3)),add=TRUE)

}
\keyword{datasets}

\eof
\name{galton}
\alias{galton}
\docType{data}
\title{ Galton's height data for parents and children}
\description{
  Data set from tabulated data set used by Galton in 1885 to study the
  relationship between a parent's height and their childrens.
}
\usage{data(galton)}
\format{
  A data frame with 928 observations on the following 2 variables.
  \describe{
    \item{child}{The child's height}
    \item{parent}{The \dQuote{midparent} height}
  }
}
\details{
  The midparent's height is an average of the fathers height and 1.08 times
  the mother's. In the data there are 205 different parents and 928 children.
  The data here is truncated at the ends for both parents and
  children so that it can be treated as numeric data. The data were
  tabulated and consequently made discrete. The \code{father.son} data set is
  similar data used by Galton and is continuous.
}
\source{
  This data was found at
  \url{http://www.bun.kyoto-u.ac.jp/~suchii/galton86.html}.

  See also the data.set \link{father.son} which was found from
  \url{http://stat-www.berkeley.edu/users/juliab/141C/pearson.dat}. 
}
\examples{
data(galton)
plot(galton)
## or with some jitter.
plot(jitter(child,5) ~ jitter(parent,5),galton)
## sunflowerplot shows flowers for multiple plots (Thanks MM)
sunflowerplot(galton)
}
\keyword{datasets}

\eof
\name{getAnswer}
\alias{getAnswer}
\title{Display answers to selected problems }
\description{
  Displaysanswers to selected problems  in the system's web browser .
}
\usage{
getAnswer(chapter = NULL, problem = NULL)
}
\arguments{
  \item{chapter}{The chapter number}
  \item{problem}{The problems number}
  Not all answers are available.
}
\details{
  Some selected answers from the problems in \emph{Using R for
  Introductory Statistics} are available from the webpage
  \url{http://www.math.csi.cuny.edu/UsingR}. This function will display
  them one-by-one in the browser.
}
\value{
  If available, opens web browser to the requested answer.
}
\author{John Verzani}
\examples{
getAnswer()
}
\keyword{ utilities }% at least one, from doc/KEYWORDS

\eof
\name{grades}
\alias{grades}
\docType{data}
\title{ Current and previous grades}
\description{
  A dataframe of a students grade and their grade in their previous
  class. Graded on American A-F scale.
}
\usage{data(grades)}
\format{ A dataframe of 122 rows with 2 columns
  \describe{
    \item{prev}{The grade in the previous class in the subject matter}
    \item{grade}{The grade in the current class}
  }
}
\examples{
data(grades)
table(grades)
}
\keyword{datasets}

\eof
\name{grip}
\alias{grip}
\docType{data}
\title{Effects of cross-country ski-pole grip}
\description{
  Simulated data set investigating effects of cross-country ski-pole grip.
}
\usage{data(grip)}
\format{
  A data frame with 36 observations on the following 4 variables.
  \describe{
    \item{UBP}{Measurement of upper-body power}
    \item{person}{One of four skiers}
    \item{grip.type}{Either classic, modern, or integrated.}
    \item{replicate}{a numeric vector}
  }
}
\details{
  Based on a study done at
  \url{http://www.montana.edu/wwwhhd/movementscilab/}
  mentioned at \url{http://www.xcskiworld.com/}. The study investigates
  the effect of grip type on upper body power. As this influences
  performance in races, presumably a skier would prefer the grip that
  provides the best power output.
}
\examples{
data(grip)
ftable(xtabs(UBP ~ person + replicate + grip.type,grip))
}
\keyword{datasets}

\eof
\name{hall.fame}
\alias{hall.fame}
\docType{data}
\title{Data frame containing baseball statistics including Hall of Fame
membership}
\description{
  A data frame containing baseball statistics for several players.
}
\usage{data(hall.fame)}
\format{
  A data frame with 1340 observations on the following 28 variables.
  \describe{
    \item{first}{first name}
    \item{last}{last name}
    \item{seasons}{Seasons played}
    \item{games}{Games played}
    \item{AB}{Official At Bats}
    \item{runs}{Runs scored}
    \item{hits}{hits}
    \item{doubles}{doubles}
    \item{triples}{triples numeric vector}
    \item{HR}{Home runs}
    \item{RBI}{Runs batted in}
    \item{BB}{Base on balls}
    \item{SO}{Strike outs}
    \item{BA}{Batting Average}
    \item{OBP}{On Base percentage}
    \item{SP}{Slugging Percentage}
    \item{AP}{Adjusted productions}
    \item{BR}{batting runs}
    \item{ABRuns}{adjusted batting runs}
    \item{Runs.Created}{Runs created}
    \item{SB}{Stolen Bases}
    \item{CS}{Caught stealing}
    \item{Stolen.Base.Runs}{Runs scored by stealing}
    \item{Fielding.Average}{Fielding average}
    \item{Fielding.Runs}{Fielding runs}
    \item{Primary.Position.Played}{    C = Catcher, 
    1 = First Base, 
    2 = Second Base, 
    3 = Third Base, 
    S = Shortstop, 
    O = Outfield, and 
    D = Designated hitter}
    \item{Total.Player.Rating}{a numeric vector}
    \item{Hall.Fame.Membership}{    Not a member, 
    Elected by the BBWAA, or
    Chosen by the Old Timers Committee or Veterans Committee}
  }
}
\details{
  The sport of baseball lends itself to the collection of data. This
  data set contains many variables used to assess a players
  career. The Hall of Fame is reserved for outstanding players as judged
  initially by the Baseball Writers Association and subsequently by the
  Veterans Committee.  
}
\source{
  This data set was submitted to the \emph{Journal of Statistical
  Education},
  \url{http://www.amstat.org/publications/jse/secure/v8n2/datasets.cochran.new.cfm},
  by James J. Cochran.
}
\examples{
data(hall.fame)
hist(hall.fame$OBP)
with(hall.fame,last[Hall.Fame.Membership != "not a member"])
}
\keyword{datasets}

\eof
\name{healthy}
\alias{healthy}
\docType{data}
\title{Healthy or not?}
\description{
  Data on whether a patient is healthy with two covariates.
}
\usage{data(healthy)}
\format{
  A data frame with 32 observations on the following 3 variables.
  \describe{
    \item{p}{One covariate}
    \item{g}{Another covariate}
    \item{healthy}{0 is healthy, 1 is not}
  }
}
\details{
  Data on health with information from two unspecified covariates.
}
\examples{
data(healthy)
library(MASS)
stepAIC(glm(healthy ~ p + g, healthy, family=binomial))
}
\keyword{datasets}

\eof
\name{homedata}
\alias{homedata}
\docType{data}
\title{ Property assessments for Maplewood NJ }
\description{
  This data sets contains a random sampling of property assessments for
  residences in Maplewood N.J. for the years 1970 and 2000. 
}
\usage{data(homedata)}
\format{
  A data frame with 150 observations on the following 2 variables.
  \describe{
    \item{y1970}{Assessed value of home in 1970 (U.S. dollars)}
    \item{y2000}{Assessed value of home in 2000 (U.S. dollars)}
  }
}
\details{
  The township of Maplewood was obligated to reassess property values
  after 30 years. This dataset shows some of the changes that occurred
  during that time to the assessed values. Many homes went up
  substantially in value.
}
\source{
  The full dataset was published during a discussion on
  \url{http://www.maplewoodonline.com}. This is a random sampling of just the
  assessed values.
}
\examples{
data(homedata)
plot(homedata)
abline(lm(y2000 ~ y1970, data=homedata))
}
\keyword{datasets}

\eof
\name{kid.weights}
\alias{kid.weights}
\docType{data}
\title{Weight and height measurement for a sample of U.S. children}
\description{
  A sample from the data presented in the NHANES III survey
  (\url{http://www.cdc.gov/nchs/nhanes.htm}). This survey is used to
  form the CDC Growth Charts (\url{http://www.cdc.gov/growthcharts}) for
  children.
}
\usage{data(kid.weights)}
\format{
  A data frame with 250 observations on the following 4 variables.
  \describe{
    \item{age}{Age in months}
    \item{weight}{weight in pounds}
    \item{height}{height in inches}
    \item{gender}{Male of Female}
  }
}
\source{
  This data is extracted from  the NHANES III survey:
  \url{http://www.cdc.gov/nchs/nhanes.htm}.
}
\examples{
data(kid.weights)
attach(kid.weights)
plot(weight,height,pch=as.character(gender))
## find the BMI -- body mass index
m.ht = height*2.54/100        # 2.54 cm per inch
m.wt = weight / 2.2046        # 2.2046 lbs. per kg
bmi = m.wt/m.ht^2
hist(bmi)
}
\keyword{datasets}

\eof
\name{last.tie}
\alias{last.tie}
\docType{data}
\title{ Last tie in 100 coin tosses}
\description{
  Toss a coin 100 times and keep a running count of the number of heads
  and the number of tails. Record the times when the number is tied and
  report the last one. The distribution will have an approximate
  \dQuote{arc-sine} law or well-shaped distribution.
}
\usage{data(last.tie)}
\format{
  200 numbers between 0 and 100 indicating when the last tie was.
}
\details{
  This data comes from simulating the commands:
  \command{x = cumsum(sample(c(-1,1),100,replace=T))}

  and then finding the
  last tie with

  \command{last.tie[i]<-max(0,max(which(!sign(x) ==
    sign(x[length(x)]))))}. 
}
\examples{
data(last.tie)
hist(last.tie)
}
\keyword{datasets}

\eof
\name{lawsuits}
\alias{lawsuits}
\docType{data}
\title{ Law suit settlements}
\description{
  
  A simulated dataset on the settlement amount of 250 lawsuits based on
  values reported by Class Action Reports.
}
\usage{data(lawsuits)}
\format{
  The format is:
 num [1:250] 16763 10489 17693 14268   442 ...
}
\details{
  Class Action Reports  completed an extensive survey of attorney fee
  awards from 1,120 common fund class actions (Volume 24, No. 2,
  March/April 2003). The full data set is available for a fee. This data
  is simulated from the values published in an excerpt.
}
\source{
  \url{http://www.classactionreports.com/classactionreports/attorneyfee.htm}
}
\references{
  See also "Study Disputes View of Costly Surge in Class-Action Suits"
  by Jonathan D. Glater in the January 14, 2004 New York Times which
  cites a Jan. 2004 paper in the \emph{Journal of Empirical Legal Studies} by
  Eisenberg and Miller.
}
\examples{
data(lawsuits)
mean(lawsuits)
median(lawsuits)
}
\keyword{datasets}

\eof
\name{mandms}
\alias{mandms}
\docType{data}
\title{Proportions of colors in various M and M's varieties}
\description{
  A bag of the candy M and M's has many different colors. Each large
  production batch is blended to the ratios given in this data set. The
  batches are thoroughly mixed and then the individual packages are
  filled by weight using high-speed equipment, not by count. 
}
\usage{data(mandms)}
\format{
  A data frame with 5 observations on the following 6 variables.
  \describe{
    \item{blue}{percentage of blue}
    \item{brown}{percentage of brown}
    \item{green}{percentage of green}
    \item{orange}{percentage of orange}
    \item{red}{percentage of red}
    \item{yellow}{percentage of yellow}
  }
}
\source{
  This data is attributed to an email sent by Masterfoods USA, A Mars,
  Incoporated Company. This email was archived at the Math Forum,
  \url{http://www.mathforum.org}.
}
\examples{
data(mandms)
bagfull = c(15,34,7,19,29,24)
names(bagfull) = c("blue","brown","green","orange","red","yellow")
prop = function(x) x/sum(x)
chisq.test(bagfull,p = prop(mandms["milk chocolate",]))
chisq.test(bagfull,p = prop(mandms["Peanut",]))
}
\keyword{datasets}

\eof
\name{math}
\alias{math}
\non_function{}
\title{ Standardized math scores }
\description{
  Standardized math scores
}
\usage{data(math)}
\format{
  The format is:
 num [1:30] 44 49 62 45 51 59 57 55 70 64 ...
}
\source{
  From Larry Kitchens, \emph{Exploring Statistics}, Duxbury Press.
}
\examples{
data(math)
hist(math)
}
\keyword{datasets}

\eof
\name{maydow}
\alias{maydow}
\docType{data}
\title{ Dow Jones industrial average and May maximum temperature}
\description{
  A data set of both the Dow Jones industrial average and the maximum
  daily temperature in New York City for May 2003.
}
\usage{data(maydow)}
\format{
  A data frame with 21 observations on the following 3 variables.
  \describe{
    \item{Day}{Day of the month}
    \item{DJA}{The daily close of the DJIQ}
    \item{max.temp}{Daily maximum temperature in Central Park}
  }
}
\details{
  Are stock traders influenced by the weather? This dataset looks
  briefly at this question by comparing the daily close of the Dow Jones
  industrial average with the maximum daily temperature for the month of
  May 2003. This month was rainy and unseasonably cool weather wise, yet
  the DJIA did well.
}
\source{
  The DJIA data is from \url{http://finance.yahoo.com} the temperature data from
  \url{http://www.noaa.gov}. 
}
\examples{
data(maydow)
attach(maydow)
plot(max.temp,DJA)
plot(max.temp[-1],diff(DJA))
}
\keyword{datasets}

\eof
\name{midsize}
\alias{midsize}
\docType{data}
\title{ Price of new and used of three mid-sized cars}
\description{
  New and used prices of three popular mid-sized cars.
}
\usage{data(midsize)}
\format{
  A data frame with 15 observations on the following 4 variables.
  \describe{
    \item{Year}{2004 is new car price, others are for used car}
    \item{Accord}{Honda Accord}
    \item{Camry}{Toyota Camry}
    \item{Taurus}{Ford Taurus}
  }
}
\details{
  The value of a car depreciates over time. This data gives the price of a
  new car and values of similar models for previous years as reported by
  \url{http://www.edmunds.com}.
}
}
\examples{
data(midsize)
plot(Accord ~ I(2004-Year), data = midsize)
}
\keyword{datasets}

\eof
\name{mw.ages}
\alias{mw.ages}
\docType{data}
\title{ Age distribution in year 2000 in Maplewood New Jersey }
\description{
  Age distribution in Maplewood New Jersey, a suburb of New York
  City. Data is broken down by Male and Female.
}
\usage{data(mw.ages)}
\format{
  A data frame with 103 observations on the following 2 variables.
  \describe{
    \item{Male}{Counts per age group. Most groups are 1 year, except for
    100-104, 105-110, 110+}
    \item{Female}{Same}
  }
}
\source{
  US Census 2000 data from \url{http://factfinder.census.gov/}
}
\examples{
data(mw.ages)
barplot(mw.ages$Male + mw.ages$Female)
}
\keyword{datasets}

\eof
\name{nba.draft}
\alias{nba.draft}
\docType{data}
\title{ NBA draft lottery odds for 2002}
\description{
  The NBA draft in 2002 has a lottery
}
\usage{data(nba.draft)}
\format{
  A data frame with 13 observations on the following 2 variables.
  \describe{
    \item{Team}{Team name}
    \item{Record}{The team won-loss record}
    \item{Balls}{The number of balls (of 1000) that this team has in the
    lottery selection}
  }
}
\details{
  The NBA draft has a lottery to determing the top 13 placings. The odds
  in the lottery are determined by the won-loss record of the team, with
  poorer records having better odds of winning.
}
\source{
  Data is taken from \url{http://www.nba.com/news/draft_ties_020424.html}.
}
\examples{
data(nba.draft)
top.pick = sample(row.names(nba.draft),1,prob = nba.draft$Balls)
}
\keyword{datasets}

\eof
\name{normtemp}
\alias{normtemp}
\docType{data}
\title{ Body temperature and heart rate of 130 health individuals}
\description{
  A data set used to investigate the claim that \dQuote{normal} temperature is
  98.6 degrees. 
}
\usage{data(normtemp)}
\format{
  A data frame with 130 observations on the following 3 variables.
  \describe{
    \item{temperature}{normal body temperature}
    \item{gender}{Gender 1 = male, 2 = female}
    \item{hr}{Resting heart rate}
  }
}
\details{
  Is normal body temperature 98.6 degrees Fahrenheit? This dataset was
  constructed to match data presented in an are article intending to
  establish the true value of \dQuote{normal} body temperature.
}
\source{
  This data set was contributed by Allen L. Shoemaker to the
  \emph{Journal of Statistics Education},
  \url{http://www.amstat.org/publications/jse/datasets/normtemp.txt}.
}
\references{
  Data set is simulated from values contained in 
Mackowiak, P. A., Wasserman, S. S., and Levine, M. M.  (1992), "A
Critical Appraisal of 98.6 Degrees F, the Upper Limit of the Normal Body
Temperature, and Other Legacies of Carl Reinhold August Wunderlich,"
\emph{Journal of the American Medical Association}, 268, 1578-1580.
}
\examples{
data(normtemp)
hist(normtemp$temperature)
t.test(normtemp$temperature,mu=98.2)
summary(lm(temperature ~ factor(gender), normtemp))
}
\keyword{datasets}

\eof
\name{npdb}
\alias{npdb}
\docType{data}
\title{ National Practioner Data Bank }
\description{
  Selected variables from the publicly available data from the National
  Practioner Data Bank (NPDB).
}
\usage{data(npdb)}
\format{
  A data frame with 6797 observations on the following 6 variables. 
  \describe{
    \item{state}{2 digit abbreviation of state}
    \item{field}{Field of practice}
    \item{age}{Age of practictioner (rounded down to 10s digit)}
    \item{year}{Year of claim}
    \item{amount}{Dollar amount of reward}
    \item{ID}{a practioner ID, masked for anonymity}
  }

  The variable names do not match the original. The codings for
  \code{field} come from a document on \url{http://63.240.212.200/publicdata.html}.
}

\details{

  This dataset excerpts some interesting variables from the NPDB for the
  years 2000-2003. The question of capping medical malpractice awards to
  lower insurance costs is currently being debated nationwide
  (U.S.). This data is a primary source for determining this debate.

  
  A quotation from  \url{http://www.npdb-hipdb.com/npdb.html}:
  
  \dQuote{The legislation that led to the creation of the NPDB was
  enacted the U.S. Congress believed that the increasing occurrence of
  medical malpractice litigation and the need to improve the quality of medical
  care had become nationwide problems that warranted greater efforts than
  any individual State could undertake. The intent is to improve the
  quality of health care by encouraging State licensing boards, hospitals
  and other health care entities, and professional societies to identify
  and discipline those who engage in unprofessional behavior; and to
  restrict the ability of incompetent physicians, dentists, and other
  health care practitioners to move from State to State without disclosure
  or discovery of previous medical malpractice payment and adverse action
  history. Adverse actions can involve licensure, clinical privileges,
  professional society membership, and exclusions from Medicare and
  Medicaid.}
}

\source{
  This data came from \url{http://www.npdb-hipdb.com/npdb.html}
}
\examples{
data(npdb)
table(table(npdb$ID))		# big offenders
hist(log(npdb$amount))		# log normal?
}
\keyword{datasets}

\eof
\name{nym.2002}
\alias{nym.2002}
\docType{data}
\title{Random sample of 2002 New York City Marathon finishers}
\description{
  A random sample of finishers from the New York City Marathon.
}
\usage{data(nym.2002)}
\format{
  A data frame with 1000 observations on the following 5 variables.
  \describe{
    \item{place}{Place in the race}
    \item{gender}{What gender}
    \item{age}{Age on day of race}
    \item{home}{Indicator of hometown or nation}
    \item{time}{Time in minutes to finish}
  }
}
\details{
  Each year thousands of particpants line up to run the New York City
  Marathon. This list is a random sample from the finishers.
}
\source{
  From the New York City Road Runners web site \url{http://www.nyrrc.org}
}
\examples{
data(nym.2002)
with(nym.2002, cor(time,age))
}
\keyword{datasets}

\eof
\name{oral.lesion}
\alias{oral.lesion}
\docType{data}
\title{Oral lesion location by town}
\description{
  A data set on oral lesion location for three Indian towns.
}
\usage{data(oral.lesion)}
\format{
  A data frame with 9 observations on the following 3 variables.
  \describe{
    \item{Kerala}{a numeric vector}
    \item{Gujarat}{a numeric vector}
    \item{Andhra}{a numeric vector}
  }
}
\source{
  "Exact Inference for Categorical Data", by
  Cyrus R. Mehta and Nitin R. Patel. Found at
  \url{http://www.cytel.com/papers/sxpaper.pdf}. 
}
\examples{
data(oral.lesion)
chisq.test(oral.lesion)$p.value
chisq.test(oral.lesion,simulate.p.value=TRUE)$p.value ## exact is.0269
}
\keyword{datasets}

\eof
\name{pi2000}
\alias{pi2000}
\non_function{}
\title{first 2000 digits of pi }
\description{first 2000 digits of pi }
\usage{data(pi2000)}
\format{
  The format is:
 num [1:2000] 3 1 4 1 5 9 2 6 5 3 ...
}
\source{
  Generated by \emph{Mathematica}, \url{http://www.wolfram.com}.
}
\examples{
data(pi2000)
chisq.test(table(pi2000))
}
\keyword{datasets}

\eof
\name{primes}
\alias{primes}
\docType{data}
\title{ Primes numbers less than 2003}
\description{
  Prime numbers between 1 and 2003.
}
\usage{data(primes)}
\format{
  The format is:
 num [1:304] 2 3 5 7 11 13 17 19 23 29 ...
}
\source{
  Generated using \url{http://www.rsok.com/~jrm/printprimes.html}.
}
\examples{
data(primes)
diff(primes)
}
\keyword{datasets}

\eof
\name{reaction.time}
\alias{reaction.time}
\docType{data}
\title{Reaction time with cell phone usage}
\description{
  A simulated dataset on reaction time to an external event for subject
  using cell phones.
}
\usage{data(reaction.time)}
\format{
  A data frame with 60 observations on the following 4 variables.
  \describe{
    \item{age}{Age of participant coded as 16-24 or 25+}
    \item{gender}{Male of Female}
    \item{control}{Code to indicate if subject is using a cell phone "T"
    or is in the control group "C"}
    \item{time}{Time in seconds to react to external event}
  }
}
\details{
  Several studies indicate that cell phone usage while driving can
  effect reaction times to external events. This dataset uses simulated data
  based on values from the  NHTSA study "The Influence of the Use of
  Mobile Phones on Driver Situation Awareness". 
}
\source{
  The NHTSA study may be found at \url{http://www-nrd.nhtsa.dot.gov/departments/nrd-13/driver-distraction/PDF/2.PDF}
}
\references{
  This study and others are linked from the web page \url{http://www.accidentreconstruction.com/research/cellphones/}.
}
\examples{
data(reaction.time)
boxplot(time ~ control, data = reaction.time)
}
\keyword{datasets}

\eof
\name{reddrum}
\alias{reddrum}
\docType{data}
\title{Growth of red drum}
\description{
  Simulated length-at-age data for the red drum. 
}
\usage{data(reddrum)}
\format{
  A data frame with 100 observations on the following 2 variables.
  \describe{
    \item{age}{age}
    \item{length}{a numeric vector}
  }
}
\details{
  This data is simulated from values reported in a paper by Porch,
  Wilson and Nieland titled "A new growth model for red drum (Sciaenops
  ocellaus) that accommodates seasonal and ontogenic changes in growth
  rates" which appeard in \emph{Fishery Bulletin} 100(1)
  (\url{http://fishbull.noaa.gov/1001/por.pdf}). They attribute the data
  to Beckman et. al and say it comes from measurements in the Northern
  Gulf of Mexico, between September 1985 and October 1998.
}
\examples{
data(reddrum)
plot(length ~ age, reddrum)
}
\keyword{datasets}

\eof
\name{salmon.rate}
\alias{salmon.rate}
\docType{data}
\title{Simulated Data on Rate of Recruitment for Salmon}
\description{
  The Ricker model is used to model the relationship of recruitment of a
  salmon species versus the number of spawners. The model has two
  parameters, a rate of growth at small numbers and a decay rate at large
  numbers. This data set is simulated data for 83 different recordings
  using parameters found in a paper by Chen and Holtby.
}
\usage{data(salmon.rate)}
\format{
  The format is:
  83 numbers on decay rates.
}
\details{
  The Ricker model for recruitment modeled by spawner count \deqn{R_t =
  S_t e^{a - bS_t}}{S exp(a-bS)} The paramter \eqn{b} is a decay rate
  for large values of \eqn{S}. In the paper by Chen and Holtby, they
  studied 83 datasets and found that \eqn{b} is log-normally distributed. The
  data is simulated from their values to illustrate a log normal
  distribution.
}

\source{
  These values are from D.G. Chen and L. Blair Holtby, \dQuote{A regional
    meta-model for stock recruitment analysis using an empirical
    Bayesian approach}, found at \url{http://www.iphc.washington.edu/}.


  }


\examples{
data(salmon.rate)
hist(log(salmon.rate))
}
\keyword{datasets}

\eof
\name{samhda}
\alias{samhda}
\docType{data}
\title{ Substance Abuse and Mental Health Data for teens }
\description{
  A data frame containing data on health behaviour for school-aged children.
}
\usage{data(samhda)}
\format{
  A data frame with 600 observations on the following 9 variables.
  \describe{
    \item{wt}{A numeric weight used in sampling}
    \item{gender}{1=Male, 2=Female, 7=not recorded}
    \item{grade}{1 = 6th, 2 = 8th, 3 = 10th}
    \item{live.with.father}{1 = Y, 2 = N}
    \item{amt.smoke}{Amount of days you smoked cigarettes in last 30. 1 = all 30, 2=
    20-29, 3 = 10-19, 4 = 6-9, 5= 3-5, 6 = 1-2, 7=0}
    \item{alcohol}{Have you ever drank alcohol, 1 = Y, 2 = N}
    \item{amt.alcohol}{Number of days in last 30 in which you drank
      alcohol }
    \item{marijuana}{Ever smoke marijuana. 1 = Y, 2= N}
    \item{amt.marijuana}{Number of days in lst 30 that marijuana was
      used. 1 = Never used, 2 = all 30, 3 =
      20-29, 4 = 10-19, 5 = 6-9, 6 = 3-5, 7 = 1-2, 8 =Used, but not in
      last 30 days}
  }
  }
\details{
  A data frame containing data on health behaviour for school-aged children.
}
\source{
  This data is sampled from the data set  "Health Behavior in School-Aged
  Children, 1996: [United States]" collected by the World Health
  Organization, \url{http://www.icpsr.umich.edu/}. It is available at
  the Substance Abuse and Mental Health Data Archive (SAMHDA). Only
  complete cases are given.
}
\examples{
data(samhda)
attach(samhda)
table(amt.smoke)
}
\keyword{datasets}

\eof
\name{scatter.with.hist}
\alias{scatter.with.hist}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Scatterplot with histograms }
\description{
  Draws a scatterplot of the data, and histogram in the margins. A
   trend line can be added, if desired.
}
\usage{
scatter.with.hist(x, y,
  hist.col = gray(0.95),
  trend.line = "lm",
   ...)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{x}{ numeric predictor }
  \item{y}{ numeric response variables }
  \item{hist.col}{ color for histogram }

  \item{trend.line}{ Draw a trend line using \code{\link{lm}},
    \code{\link{supsmu}} or \code{\link{lowess}}. Use \code{NULL} for
    none.}
  
  \item{\dots}{ Passed to \code{\link{plot}} command for scatterplot} }

\value{
  Draws the graphic. No return value.
}
\references{ This example comes from the help page for \code{\link{layout}}. }
\author{ John Verzani }
\seealso{ \code{\link{layout}} }
\examples{
data(emissions)
attach(emissions)
scatter.with.hist(perCapita,CO2)
}
\keyword{ hplot }% at least one, from doc/KEYWORDS
\keyword{ multivariate }% __ONLY ONE__ keyword per line

\eof
\name{scrabble}
\alias{scrabble}
\docType{data}
\title{ Distribution of Scrabble pieces}
\description{
  Distribution and point values of letters in Scrabble.
}
\usage{data(scrabble)}
\format{
  A data frame with 27 observations on the following 3 variables.
  \describe{
    \item{piece}{Which piece}
    \item{points}{point value}
    \item{frequency}{Number of pieces}
  }
}
\details{
  Scrabble is a popular board game based on forming words from the
  players' pieces. These consist of letters drawn from a pile at
  random. The game has a certain frequency of letters given by this
  data. These match fairly well with the letter distribution of the
  English language.
}
\examples{
data(scrabble)
## perform chi-squared analysis on long string. Is it in English?
quote = " R is a language and environment for statistical computing  \
and graphics. It is a GNU project which is similar to the S language \
and environment which was developed at Bell Laboratories (formerly   \
AT&T, now Lucent Technologies) by John Chambers and colleagues. R    \
can be considered as a different implementation of S. There are      \
some important differences, but much code written for S runs         \
unaltered under R."
quote.lc = tolower(quote)
quote = unlist(strsplit(quote.lc,""))
ltr.dist = sapply(c(letters," "),function(x) sum(quote == x))
chisq.test(ltr.dist,,scrabble$freq)

}
\keyword{datasets}

\eof
\name{sim}
\alias{sim}
\title{Function to simulate sampling distributions }
\description{
  A convenient function for simulating sampling distributions 
}
\usage{
sim(n = 10, m = 250, statistic = "mean", family = "norm", ...)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{n}{size of sample }
  \item{m}{number of simulations}
  \item{statistic}{character name of statistic. For example "mean" or "median".}
  \item{family}{family name of distribution such as "norm", "exp", "unif",...}
  \item{\dots}{named parameter values for the "r" function to find the
  random samples. }
}
\value{
  Returns a data vector of length \code{m}.
}
\author{John Verzani}
\examples{

qqnorm(sim(n=10,family="exp"))
qqnorm(sim(n=10,family="t",df=3))
qqnorm(sim(n=10,family="t",statistic="median",df=3))

}
\keyword{ univar }% at least one, from doc/KEYWORDS

\eof
\name{squareplot}
\alias{squareplot}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Create a squareplot alternative to a segmented barplot }
\description{
  Create a squareplot as an alternative to a segmented barplot. Useful
  when the viewer is interested in exact counts in the categories. A
  squareplot is often used  by the \emph{New York Times}. A grid of squares
  is presented with each color representing a different category. The
  colors appear contiguously reading top to bottom, left to right. The
  colors segment the graph as a segmented bargraph, but the squares
  allow an interested reader to easily tally the counts.
}
\usage{
squareplot(x, col = gray(seq(0.5, 1, length = length(x))),
border =NULL, nrows = ceiling(sqrt(sum(x))), ncols =
ceiling(sum(x)/nrows),
xlab = deparse(substitute(x)), main = NULL,
...)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{x}{ a vector of counts}
  \item{col}{ a vector of colors }
  \item{border}{border color passed to \code{\link{polygon}}}
  \item{nrows}{number of rows}
  \item{ncols}{number of columns }
  \item{xlab}{ label for x axis }
  \item{main}{ main title}
  \item{\dots}{ passed to \code{plot.window}}
}
\value{
  Creates the graph, but has no return  value.
}
\references{ The \emph{New York Times}, \url{www.nytimes.com}. In particular,
Sports page 6, June 15, 2003. }
\author{ John Verzani }

\examples{
## A Roger Clemens Cy Young year
squareplot(c(21,7,6),col=c("blue","green","white"))
}
\keyword{ hplot }% at least one, from doc/KEYWORDS
\keyword{ univar }% at least one, from doc/KEYWORDS

\eof
\name{stud.recs}
\alias{stud.recs}
\docType{data}
\title{ Student records}
\description{
  A simulation of student records used for placement purposes
}
\usage{data(stud.recs)}
\format{
  A data frame with 160 observations on the following 6 variables.
  \describe{
    \item{seq.1}{Score on sequential 1 test}
    \item{seq.2}{Score on sequential 2 test}
    \item{seq.3}{Score on sequential 3 test}
    \item{sat.v}{SAT verbal score}
    \item{sat.m}{SAT math score}
    \item{num.grade}{grade on first math class}
    \item{letter.grade}{grade on first math class}
  }
}
\details{
  Some simulated student records for placement purpores
}
\examples{
data(stud.recs)
hist(stud.recs$sat.v)
with(stud.recs,cor(sat.v,sat.m))
}
\keyword{datasets}

\eof
\name{student.expenses}
\alias{student.expenses}
\docType{data}
\title{Some simulated data on student expenses}
\description{
  Some data for possible student expenses
}
\usage{data(student.expenses)}
\format{
  A data frame of 5 variables for 10 students. All answers are coded "\code{Y}"
  for yes, "\code{N}" for no.
  \describe{
    \item{cell.phone}{Does student have cell phone.}
    \item{cable.tv}{Does student have cable TV.}
    \item{dial.up}{Does student pay for dial-up internet access.}
    \item{cable.modem}{Does student pay for high-speed or cable modem access to internet.}
    \item{car}{Does student own a car.}
  }
}
\details{
  Sample dataset of students expenses.
}
\examples{
data(student.expenses)
attach(student.expenses)
table(dial.up,cable.modem)
}
\keyword{datasets}

\eof
\name{superbarplot}
\alias{superbarplot}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ super segmented barplot }
\description{
  Plot a barplot, with bars nested and ranging from a max to a minimum
  value. A similar graphic is used on the weather page of the \emph{New
  York Times}.
}
\usage{
superbarplot(x, names = 1:dim(x)[2], names.height = NULL,
  col = gray(seq(0.8, 0.5, length = dim(x)[1]/2)),...
)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{x}{A matrix with each pair of rows representing a min and max
  for the bar.}
  \item{names}{ Place a name in each bar. }
  \item{names.height}{ Where the names should go }
  \item{col}{ What colors to use for the bars. There should be half as
    many specified as rows of \code{x} }
  \item{...}{passed to \code{\link{plot}}. }

}
\details{
  A similar graphic on the weather page of the \emph{New York Times}
  shows bars for record highs and lows, normal highs and lows and actual
  (or predicted) highs or lows for 10 days of weather. This graphic
  succintly and elegantly displays a wealth of information. Intended as
  an illustration of the \code{\link{polygon}} function.
}
\value{
  Returns a plot, but no other values.
}
\references{ The  weather page of the \emph{New York Times} }
\author{ John Verzani }
\seealso{ \code{\link{squareplot}} }
\examples{
record.high=c(95,95,93,96,98,96,97,96,95,97)
record.low= c(49,47,48,51,49,48,52,51,49,52)
normal.high=c(78,78,78,79,79,79,79,80,80,80)
normal.low= c(62,62,62,63,63,63,64,64,64,64)
actual.high=c(80,78,80,68,83,83,73,75,77,81)
actual.low =c(62,65,66,58,69,63,59,58,59,60)
x=rbind(record.low,record.high,normal.low,normal.high,actual.low,actual.high)
the.names=c("S","M","T","W","T","F","S")[c(3:7,1:5)]
superbarplot(x,names=the.names)

}
\keyword{ hplot }% at least one, from doc/KEYWORDS
\keyword{ multivariate }% __ONLY ONE__ keyword per line

\eof
\name{tastesgreat}
\alias{tastesgreat}
\docType{data}
\title{Does new goo taste great?}
\description{
  Fictitious data on taste test for new \emph{goo}
}
\usage{data(tastesgreat)}
\format{
  A data frame with 40 observations on the following 3 variables.
  \describe{
    \item{gender}{a factor with levels \code{Female} \code{Male}}
    \item{age}{a numeric vector}
    \item{enjoyed}{1 if enjoyed, 0 otherwise}
  }
}
\details{
  Fictitious data on a taste test with gender and age as covariates.
}
\examples{
data(tastesgreat)
summary(glm(enjoyed ~ gender + age, data=tastesgreat, family=binomial))
}
\keyword{datasets}

\eof
\name{too.young}
\alias{too.young}
\docType{data}
\title{ What age is too young for a male to data a female?}
\description{
  In U.S. culture, an older man dating a younger woman is not uncommon,
  but when the age difference becomes too great is may seem to some to
  be unacceptable. This data set is a survey of 10 people with their
  minimum age for an acceptable partner for a range of ages for the
  male. A surprising rule of thumb (in the sense that someone took the
  time to figure this out) for the minimum is half the age plus
  seven. Does this rule hold for this data set?
}
\usage{data(too.young)}
\format{
  A data frame with 80 observations on the following 2 variables.
  \describe{
    \item{Male}{a numeric vector}
    \item{Female}{a numeric vector}
  }
}
\examples{
data(too.young)
lm(Female ~ Male, data=too.young)
}
\keyword{datasets}

\eof
\name{twins}
\alias{twins}
\docType{data}
\title{Burt's IQ data for twins}
\description{
  IQ data of Burt on identical twins that were separated near birth.
}
\usage{data(twins)}
\format{
  A data frame with 27 observations on the following 3 variables.
  \describe{
    \item{Foster}{IQ for twin raised with foster parents}
    \item{Biological}{IQ for twin raised with biological parents}
    \item{Social}{Social status of biological parents}
  }
}
\details{
  
}
\source{
  This data comes from the R package that accompanies Julian Faraway's
  notes \emph{Practical Regression and Anova in R} (now a book).
}
\examples{
data(twins)
plot(Foster ~ Biological, twins)
}
\keyword{datasets}

\eof
\name{u2}
\alias{u2}
\docType{data}
\title{Song and lengths for U2 albums}
\description{
  Song titles and lengths of U2 albums from 1980 to 1997.
}
\usage{data(u2)}
\format{
  The data is stored as  a list with names. Each list entry correspond
  to an album stored as a vector. The values of the vector are the song
  lengths in seconds and the names are the track titles.
}
\source{
  \url{http://www.u2station.com/u2ography.html}
}
\examples{
data(u2)
sapply(u2,mean)			# average track length
max(sapply(u2,max))		# longest track length
sort(unlist(u2))		# lengths in sorted order
}
\keyword{datasets}

\eof
\name{urchin.growth}
\alias{urchin.growth}
\docType{data}
\title{ Data on growth of sea urchins}
\description{
  Data on growth of sea urchins.
}
\usage{data(urchin.growth)}
\format{
  A data frame with 250 observations on the following 2 variables.
  \describe{
    \item{age}{Estimated age of sea urchin}
    \item{size}{Measurement of size}
  }
}
\details{
  Data is sampled from a data set that accompanies the thesis of P. Grosjean.
}
\source{
  Thesis was found at \url{http://www.sciviews.org/_pgrosjean}.
}
\examples{
data(urchin.growth)
plot(jitter(size) ~ jitter(age), data=urchin.growth)
}
\keyword{datasets}

\eof
\name{yellowfin}
\alias{yellowfin}
\docType{data}
\title{Yellow fin tuna catch rate in Tropical Indian Ocean}
\description{
  Mean catch rate of yellow fin tuna in Tropical Indian Ocean for the
  given years.
}
\usage{data(yellowfin)}
\format{
  A data frame with 49 observations on the following 2 variables.
  \describe{
    \item{year}{The year}
    \item{count}{Mean number of fish per 100 hooks cast}
  }
}
\details{
  Estimates for the mean number of fish caught per 100 hooks are given
  for a number of years. This can be used to give an estimate for the
  size, or biomass, of the species during these years assuming the more
  abundant the fish, the larger the mean. In practice this assumption is
  viewed with a wide range of attitudes.
}
\source{
  This data is read from a graph that accompanies Myers RA, Worm B
  (2003) \dQuote{Rapid worldwide depletion of predatory fish
  communities}. \emph{Nature} 423:280-283.
}
\references{
  See also
  \url{http://www.soest.hawaii.edu/PFRP/large_pelagic_predators.html}
  for rebuttals to the Myers and Worm article.
}
\examples{
data(yellowfin)
plot(yellowfin)
}
\keyword{datasets}

\eof
